@@ -18,6 +18,7 @@
 
 #include "importhelper.h"
 #include "window/mainwindow.h"
+#include "palapeli_version.h"
 
 #include <ctime>
 #include <KAboutData>
@@ -30,13 +31,12 @@
 
 int main(int argc, char** argv)
 {
-    qsrand(time(0));
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("palapeli");
 
-    KAboutData about(QStringLiteral("palapeli"), i18nc("The application's name", "Palapeli"), QStringLiteral("2.1"), i18n("KDE Jigsaw Puzzle Game"), KAboutLicense::GPL, i18n("Copyright 2009, 2010, Stefan Majewsky"));
-    about.addAuthor(i18n("Stefan Majewsky"), QString(), QStringLiteral("majewsky@gmx.net"), QStringLiteral("http://majewsky.wordpress.com"));
+    KAboutData about(QStringLiteral("palapeli"), i18nc("The application's name", "Palapeli"), PALAPELI_VERSION_STRING, i18n("KDE Jigsaw Puzzle Game"), KAboutLicense::GPL, i18n("Copyright 2009, 2010, Stefan Majewsky"));
+    about.addAuthor(i18n("Stefan Majewsky"), QString(), QStringLiteral("majewsky@gmx.net"), QStringLiteral("https://majewsky.wordpress.com/"));
     about.addCredit (i18n ("Johannes Loehnert"),
             i18n ("The option to preview the completed puzzle"),
             QStringLiteral("loehnert.kde@gmx.de"));
